@@ -1,6 +1,6 @@
 package SQLite::Work;
 {
-  $SQLite::Work::VERSION = '0.12';
+  $SQLite::Work::VERSION = '0.13';
 }
 use strict;
 use warnings;
@@ -11,7 +11,7 @@ SQLite::Work - report on and update an SQLite database.
 
 =head1 VERSION
 
-version 0.12
+version 0.13
 
 =head1 SYNOPSIS
 
@@ -358,7 +358,6 @@ sub do_disconnect {
 	where=>\%where,
 	not_where=>\%not_where,
 	sort_by=>\@sort_by,
-	sort_reversed=>\%sort_reversed,
 	show=>\@show,
 	distinct=>0,
 	headers=>\@headers,
@@ -540,11 +539,8 @@ be shown when a L<row_template> has not been given.
 =item sort_by
 
 An array of column names by which the result should be sorted.
-
-=item sort_reversed
-
-A hash of column names where the sorting given in L<sort_by> should
-be reversed.
+If the column name is prefixed with a "-", the sort order should
+be reversed for that column.
 
 =item table
 
@@ -613,8 +609,7 @@ sub do_report {
 	headers=>[],
 	header_start=>1,
 	groups=>[],
-	sort_by=>[],
-	sort_reversed=>{},
+	sort_by=>undef,
 	not_where=>{},
 	where=>{},
 	show=>[],
@@ -655,7 +650,6 @@ sub do_report {
 	where=>\%where,
 	not_where=>\%not_where,
 	sort_by=>\@sort_by,
-	sort_reversed=>\%sort_reversed,
 	show=>\@show,
 	headers=>\@headers,
 	groups=>\@groups,
@@ -706,8 +700,7 @@ sub do_multi_page_report {
 	headers=>[],
 	header_start=>1,
 	groups=>[],
-	sort_by=>[],
-	sort_reversed=>{},
+	sort_by=>undef,
 	not_where=>{},
 	where=>{},
 	show=>[],
@@ -869,7 +862,6 @@ sub do_multi_page_report {
 	where=>\%where,
 	not_where=>\%not_where,
 	sort_by=>\@sort_by,
-	sort_reversed=>\%sort_reversed,
 	show=>\@show,
 	headers=>\@headers,
 	header_start=>1,
@@ -924,8 +916,7 @@ sub do_split_report {
 	headers=>[],
 	header_start=>1,
 	groups=>[],
-	sort_by=>[],
-	sort_reversed=>{},
+	sort_by=>undef,
 	not_where=>{},
 	where=>{},
 	show=>[],
@@ -1000,10 +991,10 @@ sub do_split_report {
 					{$args{table}}->{$split_col},
 					name=>$split_col)
 	    if ($self->{default_format}->{$args{table}}->{$split_col});
-	warn "val=$val, niceval=$niceval\n" if $args{debug};
 
 	my $valbase = $self->{_tobj}->convert_value(value=>$niceval,
 	    format=>$args{filename_format}, name=>$split_col);
+	warn "val=$val, niceval=$niceval, valbase=$valbase\n" if $args{debug};
 	my $outfile = sprintf("%s%s%s",
 	    $outfile_prefix, $valbase, $outfile_suffix);
 	my $outfile_link = sprintf("%s%s%s",
@@ -1564,8 +1555,7 @@ sub make_selections {
 	limit=>0,
 	page=>1,
 	table2=>'',
-	sort_by=>[],
-	sort_reversed=>{},
+	sort_by=>undef,
 	not_where=>{},
 	where=>{},
 	show=>[],
@@ -1575,8 +1565,11 @@ sub make_selections {
     my $table = $args{table};
     my $command = $args{command};
 
-    my @sort_by = @{$args{sort_by}};
-    my %sort_reversed = %{$args{sort_reversed}};
+    my @sort_by = (!defined $args{sort_by}
+	? ()
+	: (!ref $args{sort_by}
+	    ? split(' ', $args{sort_by})
+		: @{$args{sort_by}}));
     my @columns = (@{$args{show}}
 	? @{$args{show}}
 	: $self->get_colnames($table));
@@ -1618,9 +1611,9 @@ sub make_selections {
 	$jquery .= " ORDER BY ";
 	foreach my $col (@sort_by)
 	{
-	    if ($sort_reversed{$col})
+	    if ($col =~ /^-(.*)/)
 	    {
-		push @order_by, "$col DESC";
+		push @order_by, "$1 DESC";
 	    }
 	    else
 	    {
@@ -1882,7 +1875,6 @@ sub print_select {
 	@_
     );
     my @columns = @{$args{columns}};
-    my @sort_by = @{$args{sort_by}};
     my $table = $args{table};
     my $page = $args{page};
 
@@ -1899,7 +1891,7 @@ sub print_select {
 	table=>$table,
 	table2=>$args{table2},
 	columns=>\@columns,
-	sort_by=>\@sort_by,
+	sort_by=>$args{sort_by},
 	num_pages=>$num_pages,
 	);
     my $main_title = ($args{title} ? $args{title}
@@ -2155,7 +2147,11 @@ sub format_report {
 	@_
     );
     my @columns = @{$args{columns}};
-    my @sort_by = @{$args{sort_by}};
+    my @sort_by = (!defined $args{sort_by}
+	? ()
+	: (!ref $args{sort_by}
+	    ? split(' ', $args{sort_by})
+		: @{$args{sort_by}}));
     my @headers = @{$args{headers}};
     my $header_start = $args{header_start} || 1;
     my @groups = @{$args{groups}};
